==> enterprisemodules-ora_config-3.18.3.tar.gz: enterprisemodules-ora_config-3.18.3/lib/puppet/type/ora_home_option/datamining.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/settings'

newproperty(:datamining) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Settings

  desc <<-EOD

      This resource allows you to manage(enable/disable) the Data Mining RDBMS Files option in an Oracle database home (version < 12.2).

          ora_home_option { '/u01/app/oracle/product/12.1.0/db_home1':
            ...
            datamining               => 'enabled',
            ...
          }

  EOD

  newvalues(:disabled, :enabled)
  data_type("Optional[Enum['disabled', 'enabled']]")

  to_translate_to_resource do |raw_resource|
    current_home = raw_resource['NAME']
    ora_install_homes = Facter::value('ora_install_homes') || {}
    current_home_version = ora_install_homes.dig(current_home, 'product_version')
    if current_home_version.nil?
      nil
    else
      if Gem::Version.new(current_home_version) > Gem::Version.new('12.1.0.2.0')
        nil
      else
        raw_resource['DM']
      end
    end
  end

  on_modify do
    flag = enabled? ? 'enable' : 'disable'
    oracle_home = resource.name
    ora_install_homes = Facter::value('ora_install_homes') || {}
    # Todo: get rid of settings dependency and rely on the facts, so we can also manage this property for homes that don't have a settings entry
    oh_settings_entry = configuration.select { |db, settings| settings['oracle_home'] == oracle_home }.first
    os_user = ora_install_homes.dig(oracle_home, 'os_user').nil? ? configuration_value_for(oh_settings_entry.first, 'os_user') : ora_install_homes.dig(oracle_home, 'os_user')
    command = "su - #{os_user} -c \"export ORACLE_HOME=#{oracle_home}; #{oracle_home}/bin/chopt #{flag} dm\""
    options = { :failonfail => true, :combine => true }
    Puppet::Util::Execution.execute(command, options)
  end

  private

  def enabled?
    value.to_s == 'enabled'
  end

end

==> enterprisemodules-ora_config-3.18.4.tar.gz: enterprisemodules-ora_config-3.18.4/lib/puppet/type/ora_home_option/datamining.rb <==
# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/settings'

newproperty(:datamining) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Settings

  desc <<-DESC

      This resource allows you to manage(enable/disable) the Data Mining RDBMS Files option in an Oracle database home (version < 12.2).

          ora_home_option { '/u01/app/oracle/product/12.1.0/db_home1':
            ...
            datamining               => 'enabled',
            ...
          }

  DESC

  newvalues(:disabled, :enabled)
  data_type("Optional[Enum['disabled', 'enabled']]")

  to_translate_to_resource do |raw_resource|
    current_home = raw_resource['NAME']
    ora_install_homes = Facter.value('ora_install_homes') || {}
    current_home_version = ora_install_homes.dig(current_home, 'product_version')
    if current_home_version.nil?
      nil
    elsif Gem::Version.new(current_home_version) > Gem::Version.new('12.1.0.2.0')
      nil
    else
      raw_resource['DM']
    end
  end

  on_modify do
    flag = enabled? ? 'enable' : 'disable'
    oracle_home = resource.name
    ora_install_homes = Facter.value('ora_install_homes') || {}
    # TODO: get rid of settings dependency and rely on the facts, so we can also manage this property for homes that don't have a settings entry
    oh_settings_entry = configuration.find { |_db, settings| settings['oracle_home'] == oracle_home }
    os_user = ora_install_homes.dig(oracle_home, 'os_user').nil? ? configuration_value_for(oh_settings_entry.first, 'os_user') : ora_install_homes.dig(oracle_home, 'os_user')
    command = "su - #{os_user} -c \"export ORACLE_HOME=#{oracle_home}; #{oracle_home}/bin/chopt #{flag} dm\""
    options = { :failonfail => true, :combine => true }
    Puppet::Util::Execution.execute(command, options)
  end

  private

  def enabled?
    value.to_s == 'enabled'
  end
end
